/*  -- translated by f2c (version 20100827).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     DATEC2 */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int datec2_(char *cform, integer *iy, integer *itd, ftnlen 
	cform_len)
{
    static integer id, im;
    extern /* Subroutine */ int date23_(integer *, integer *, integer *, 
	    integer *), datec3_(char *, integer *, integer *, integer *, 
	    ftnlen);

    date23_(iy, &im, &id, itd);
    datec3_(cform, iy, &im, &id, cform_len);
    return 0;
} /* datec2_ */

